#include "em_device.h"

void EMU_setup(void)
{
	EMU->PWRCFG = EMU_PWRCFG_PWRCFG_DCDCTODVDD;		// unlock DCDC registers
	EMU->DCDCMISCCTRL = 15<<16;						// set 320mA current limit
	EMU->DCDCCLIMCTRL = 1<<13;						// enable current limiter
	EMU->DCDCCTRL = 0;								// bypass DCDC
	EMU->PWRCTRL = EMU_PWRCTRL_REGPWRSEL;			// power analog blocks from DVDD
}

void CMU_setup(void)
{
	CMU->OSCENCMD = CMU_OSCENCMD_LFXOEN+CMU_OSCENCMD_LFRCODIS+CMU_OSCENCMD_AUXHFRCOEN;
	while (!(CMU->STATUS & CMU_STATUS_LFXORDY)){}	// wait for LFXO stabilize
	CMU->HFCLKSEL = CMU_HFCLKSEL_HF_HFRCO;			// select 19 MHz HFRCO as closk source
	CMU->HFBUSCLKEN0 = CMU_HFBUSCLKEN0_LE;			// enable LE clock access
	CMU->LFACLKSEL = CMU_LFACLKSEL_LFA_LFXO;		// set LFXO as LFA
	CMU->LFECLKSEL = CMU_LFECLKSEL_LFE_LFXO;
}

void GPIO_setup(void)								// configure GPIO ports
{
	CMU->HFBUSCLKEN0 |= CMU_HFBUSCLKEN0_GPIO;
	CMU->DBGCLKSEL = 1;
	(GPIO->P[3]).MODEH |= GPIO_P_MODEH_MODE8_PUSHPULL;	// red LED control

	(GPIO->P[9]).MODEH |= GPIO_P_MODEH_MODE14_PUSHPULL; // configure DC/DC pin
	(GPIO->P[9]).DOUT |= 1<<14;							// enable DC/DC booster
	(GPIO->P[8]).MODEL |= GPIO_P_MODEL_MODE1_PUSHPULL;  // configure LED1 COM pin
	(GPIO->P[8]).DOUT |= 1<<1;							// enable LED1 RGB
	(GPIO->P[3]).MODEH |= GPIO_P_MODEH_MODE11_PUSHPULL+	// enable all colors in LED1
						  GPIO_P_MODEH_MODE12_PUSHPULL+
						  GPIO_P_MODEH_MODE13_PUSHPULL;
}

void LETIMER0_setup(void)
{
	CMU->LFACLKEN0 = CMU_LFACLKEN0_LETIMER0;
	LETIMER0->CTRL = LETIMER_CTRL_COMP0TOP;			// set 1 sec period
	LETIMER0->COMP0 = 32767;
	LETIMER0->IEN = LETIMER_IEN_UF;					// enable LETIMER interrupt
	LETIMER0->CMD = LETIMER_CMD_START + LETIMER_CMD_CLEAR;
	NVIC_EnableIRQ(LETIMER0_IRQn);					// enabe Letimer Int in NVIC
}
